@@ -520,13 +520,10 @@ class Quark:
                     }
                 )
 
-        # Assign level 3 - list methods calling to the APIs
+        # Assign level 3 examine result
         combination = []
         if rule_obj.check_item[2]:
-            for method_list in self.quark_analysis.level_3_result:
-                combination.append(
-                    [method.full_name for method in method_list]
-                )
+            combination = rule_obj.api
 
         # Assign level 4 - 5 examine result if exist
         sequnce_show_up = []
@@ -537,9 +534,7 @@ class Quark:
             for item4 in self.quark_analysis.level_4_result:
                 sequnce_show_up.append(
                     {
-                        repr(
-                            item4.full_name
-                        ): self.quark_analysis.parent_wrapper_mapping[
+                        item4.full_name: self.quark_analysis.parent_wrapper_mapping[
                             item4.full_name
                         ]
                     }
@@ -550,9 +545,7 @@ class Quark:
                 for item5 in self.quark_analysis.level_5_result:
                     same_operation_show_up.append(
                         {
-                            repr(
-                                item5.full_name
-                            ): self.quark_analysis.parent_wrapper_mapping[
+                            item5.full_name: self.quark_analysis.parent_wrapper_mapping[
                                 item5.full_name
                             ]
                         }
